#!/usr/bin/perl -w

use strict;

# pamcompound v1.0.2 - erzeugt aus den Ergebnissen einer Analyse HTML-Seiten
# Copyright (C) 2001, 2002 Dirk Swiniartzki (pamela@planet-dirk.de)
#
#    This program is free software; you can redistribute it and/or
#    modify it under the terms of the GNU General Public License version 2
#    as published by the Free Software Foundation.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
#    General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#    -----------------------------------------------------------
#    Dieses Programm ist freie Software. Sie knnen es unter
#    den Bedingungen der GNU General Public License Version 2,
#    wie von der Free Software Foundation herausgegeben, weitergeben
#    und/oder modifizieren.
#
#    Die Verffentlichung dieses Programms erfolgt in der
#    Hoffnung, da es Ihnen von Nutzen sein wird, aber OHNE JEDE
#    GEWHRLEISTUNG - sogar ohne die implizite Gewhrleistung
#    der MARKTREIFE oder der EIGNUNG FR EINEN BESTIMMTEN ZWECK.
#    Details finden Sie in der GNU General Public License.
#
#    Sie sollten eine Kopie der GNU General Public License zusammen
#    mit diesem Programm erhalten haben. Falls nicht, schreiben Sie
#    an die Free Software Foundation, Inc., 675 Mass Ave, Cambridge,
#    MA 02139, USA.
#    ----------------------------------------------------------------

my $resultdir;           # Verzeichnis, in dem die Ergebnisse liegen
my $htmldir;             # Verzeichnis, in das die HTML-Dateien landen
my ($a, $b, $c);         # temporre Variablen
my @data;                # temporres Array
my @arbeitssys;          # Liste der Arbeitssysteme
my %kennzahl;            # Nimmt die Kennzahlen auf

#---------- make_index ----------
# erzeugt die index.html-Seite als bersicht
# Parameter: -
# Rckgabewerte : -

sub make_index {

   print "Erzeuge HTML-Struktur.\n";
   $a=$htmldir."index.html";

   open(INDEX, ">$a") || die("Konnt Datei $a nicht anlegen : $!\n");

   print INDEX <<INDENDHEAD;
<html>
<head>
<title>Ergebnisse LAT-Analyse</title>
<meta name="GENERATOR" content="latcompound">
</head>
<body>
<div align="center">
  <h2>Ergebnisse der LAT-Analyse</h2>
  <br>
  <a href="kennzahlen.html">Kennzahlen aller Arbeitssysteme</a><br>
  <a href="terminabweichung.html">Terminabweichung aller Auftrge</a><br>
  <br>
  <h3>Liste der Arbeitssysteme:</h3>
  <br>
INDENDHEAD

   foreach $a (@arbeitssys) {
      print INDEX "  <a href=\"$a.html\">$a</a><br>\n";}

   print INDEX <<INDENDBODY;
<br><br><br>
Danke, da&szlig; Sie LAT verwendet haben !<br>
</div>
</body>
</html>
INDENDBODY
# /

   close(INDEX);
   print "HTML-Struktur erzeugt.\n";
}

#---------- make_terminabweichung ----------
# erzeugt die Seite zur Terminabweichung
# Parameter : -
# Rckgabewerte : -

sub make_terminabweichung {
   print "Erzeuge HTML-Datei Terminabweichung.\n";
   $a=$htmldir."terminabweichung.html";
   open(TERMIN, ">$a") || die("Konnte Datei $a nicht anlegen : $!\n");

   print TERMIN <<TAEND;
<html>
<head>
<title>Terminabweichung aller Auftrge</title>
<meta name=GENERATOR" content="latcompound">
</head>
<body>
<div align="center">
  <h2>Terminabweichung</h2><br>
  <img src="./diagramme/terminabweichung.png" border="0">
  <br><br>
  <a href="index.html">zurck zur bersicht</a>
</div>
</body>
</html>
TAEND
   close(TERMIN);
   print "HTML-Datei Terminabweichung erzeugt.\n";
}

#---------- make_kennzahl ----------
# erzeugt die Kennzahltabelle in HTML
# Parameter : -
# Rckgabewerte : -

sub make_kennzahl {
   my ($a, $b, $c);       # temporre Variablen

   print "Erzeuge HTML-Datei Kennzahltabelle.\n";
   $a=$htmldir."kennzahlen.html";
   open(KENN, ">$a") || die("Konnte Datei $a nicht anlegen : $!\n");
   print KENN <<KENNEND;
<html>
<head>
   <title>Kennzahlen der Arbeitssysteme</title>
   <meta name="GENERATOR" content="latcompound">
</head>
<body>
<div align="center"><h2>Kennzahlen der Arbeitssysteme</h2><br>
   <table border="0">
      <tr>
      <td><b>Arbeitssystem</b></td>
      <td><div align="center"><b>BImin</b></div></td>
      <td><div align="center"><b>Bm</b></div></td>
      <td><div align="center"><b>Lm</b></div></td>
      <td><div align="center"><b>Lmax</b></div></td>
      <td><div align="center"><b>ZAUm</b></div></td>
      <td><div align="center"><b>ZAUs</b></div></td>
      <td><div align="center"><b>Rm</b></div></td>
      <td><div align="center"><b>ZDLmg (in BKT)</b></div></td>
      <td><div align="center"><b>ZDLmg (in h)</b></div></td>
      <td><div align="center"><b>Lgesamt</b></div></td>
      <td><div align="center"><b>Flugrad</b></div></td>
      <td><div align="center"><b>Auslastung (in %)</b></div></td>
      <td><div align="center"><b>Pnklich (in %)</b></div></td></tr>
KENNEND
#/
   foreach $b (sort keys %kennzahl) {
      print KENN "<tr><td><a href=\"$b.html\">$b</a></td>\n";
      foreach $c (0..$#{$kennzahl{$b}}) {
         print KENN "<td><div align=\"right\">$kennzahl{$b}[$c]</div></td>\n";}
      print KENN "</tr>\n";}

   print KENN <<KENNEND2;
</table><br><br>
<a href="index.html">zurck zur bersicht</a><br></div>
</body>
</html>
KENNEND2
#/

   close(KENN);
   print "Kennzahltabelle erzeugt.\n";
}

#---------- make_systeme ----------
# erzeugt fr jedes Arbeitssystem eine HTML-Seite mit den Ergebnissen
# Parameter : -
# Rckgabewerte : -

sub make_systeme {
   my ($a, $b, $c);     # temporre Variablen

   foreach $a (sort keys%kennzahl) {
      print "Erzeuge Zusammenfassung fr Arbeitssystem $a...";
      $b=$htmldir."$a.html";
      open(SYSTEM, ">$b") || die("Konnte Datei $b nicht anlegen : $!\n");

      print SYSTEM "<html>\n<head>\n<title>Ergebnisse fr Arbeitssystem $a</title>\n";
      print SYSTEM "<meta name=\"GENERATOR\" content=\"latcompound\">\n</head>\n<body>\n";
      print SYSTEM "<div align=\"center\"><h2>Analyseergebnisse fr Arbeitssystem $a</h2><br><br>\n";
      print SYSTEM "<table border=\"0\">\n";
      print SYSTEM "<tr><td><div align=\"right\"><b>BImin :</b></div></td><td>$kennzahl{$a}[0]</td></tr>\n";
      print SYSTEM "<tr><td><div align=\"right\"><b>Bm :</b></div></td><td>$kennzahl{$a}[1]</td></tr>\n";
      print SYSTEM "<tr><td><div align=\"right\"><b>Lm :</b></div></td><td>$kennzahl{$a}[2]</td></tr>\n";
      print SYSTEM "<tr><td><div align=\"right\"><b>Lmax :</b></div></td><td>$kennzahl{$a}[3]</td></tr>\n";
      print SYSTEM "<tr><td><div align=\"right\"><b>ZAUm :</b></div></td><td>$kennzahl{$a}[4]</td></tr>\n";
      print SYSTEM "<tr><td><div align=\"right\"><b>ZAUs :</b></div></td><td>$kennzahl{$a}[5]</td></tr>\n";
      print SYSTEM "<tr><td><div align=\"right\"><b>Rm :</b></div></td><td>$kennzahl{$a}[6]</td></tr>\n";
      print SYSTEM "<tr><td><div align=\"right\"><b>ZDLmg (BKT) :</b></div></td><td>$kennzahl{$a}[7]</td></tr>\n";
      print SYSTEM "<tr><td><div align=\"right\"><b>ZDLmg (h) :</b></div></td><td>$kennzahl{$a}[8]</td></tr>\n";
      print SYSTEM "<tr><td><div align=\"right\"><b>Lgesamt :</b></div></td><td>$kennzahl{$a}[9]</td></tr>\n";
      print SYSTEM "<tr><td><div align=\"right\"><b>Flugrad :</b></div></td><td>$kennzahl{$a}[10]</td></tr>\n";
      print SYSTEM "<tr><td><div align=\"right\"><b>Auslastung (%) :</b></div></td><td>$kennzahl{$a}[11]</td></tr>\n";
      print SYSTEM "<tr><td><div align=\"right\"><b>Pnklich (%) :</b></div></td><td>$kennzahl{$a}[12]</td></tr>\n";
      $c="./diagramme/dudi_$a.png";
      print SYSTEM "</table></div><br><br>\n<h3>Durchlaufdiagramm :</h3><br><br>\n<img src=\"$c\"><br><br>\n";
      $c="./diagramme/pkl_$a.png";
      print SYSTEM "<h3>Produktionskennlinie :</h3><br><br>\n<img src=\"$c\"><br><br>\n";
      $c="./diagramme/histo_ZAU_$a.png";
      print SYSTEM "<h3>Hufigkeitsverteilung ZAU :</h3><br><br>\n<img src=\"$c\"><br><br>\n";
      $c="./diagramme/histo_ZDL_$a.png";
      print SYSTEM "<h3>Hufigkeitsverteilung ZDL :</h3><br><br>\n<img src=\"$c\"><br><br>\n";
      print SYSTEM "<div align=\"center\"><a href=\"index.html\">zur bersicht</a><br>\n";
      print SYSTEM "<a href=\"kennzahlen.html\">zur Kennzahltabelle</a>\n</div>\n</body>\n</html>\n";
      close(SYSTEM);
      print " fertig.\n";}
}


#---------- Hauptprogramm ----------
# /"
print <<ANNOUNCE;
pamcompound v1.0.2 - erzeugt HTML-Seiten aus den Ergebnissen einer PameLa-Analyse
Copyright (C) 2001, 2002 Dirk Swiniartzki pamela\@planet-dirk.de

Dieses Programm ist freie Software. Sie knnen es unter
den Bedingungen der GNU General Public License Version 2,
wie von der Free Software Foundation herausgegeben, weitergeben
und/oder modifizieren.

Die Verffentlichung dieses Programms erfolgt in der
Hoffnung, da es Ihnen von Nutzen sein wird, aber OHNE JEDE
GEWHRLEISTUNG - sogar ohne die implizite Gewhrleistung
der MARKTREIFE oder der EIGNUNG FR EINEN BESTIMMTEN ZWECK.
Details finden Sie in der GNU General Public License.
ANNOUNCE

print "\nSyntax : pamcompound.plx\n\n";

print "Bitte geben Sie das Ergebnis-Verzeichnis an : ";
$resultdir=<STDIN>;
chomp($resultdir);
print "\nBitte geben Sie das HTML-Verzeichnis an : ";
$htmldir=<STDIN>;
chomp($htmldir);

print "\nLese Kennzahlen ein.\n";
$a=$resultdir."kennzahlen.csv";
open(KENNZ, $a) || die("Konnte Datei $a nicht ffnen : $!\n");
<KENNZ>;
while (<KENNZ>) {
   chomp;
   @data=split(/;/, $_); #/
   $a=shift @data;
   $kennzahl{$a}=[@data];
   push(@arbeitssys, $a);}

close(KENNZ);

make_index();
make_kennzahl();
make_terminabweichung();
make_systeme();

__END__
